@@ -50,7 +50,7 @@ public:
 
     ~Impp();
 
-    typedef QVector<Impp> List;
+    typedef QList<Impp> List;
     Q_REQUIRED_RESULT bool isValid() const;
 
     void setAddress(const QUrl &address);
@@ -84,23 +84,6 @@ public:
      */
     void setPreferred(bool preferred);
 
-#if KCONTACTS_ENABLE_DEPRECATED_SINCE(5, 88)
-    /**
-     * @deprecated Since 5.88 for lack of usage
-     */
-    KCONTACTS_DEPRECATED_VERSION(5, 88, "For lack of usage.")
-    void setParameters(const QMap<QString, QStringList> &params);
-#endif
-
-#if KCONTACTS_ENABLE_DEPRECATED_SINCE(5, 88)
-    /**
-     * @deprecated Since 5.88 for lack of usage
-     */
-    Q_REQUIRED_RESULT
-    KCONTACTS_DEPRECATED_VERSION(5, 88, "For lack of usage.")
-    QMap<QString, QStringList> parameters() const;
-#endif
-
     Q_REQUIRED_RESULT bool operator==(const Impp &other) const;
     Q_REQUIRED_RESULT bool operator!=(const Impp &other) const;
 
@@ -123,9 +106,10 @@ public:
      * Don't use these strings directly for display, instead use serviceLabel and serviceIcon.
      * @since 5.12
      */
-    static QVector<QString> serviceTypes();
+    static QList<QString> serviceTypes();
 
 private:
+    // exported for ImppTest
     void setParams(const ParameterMap &params);
     Q_REQUIRED_RESULT ParameterMap params() const;
 
@@ -138,6 +122,6 @@ KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &stream, const Impp &object
 KCONTACTS_EXPORT QDataStream &operator>>(QDataStream &stream, Impp &object);
 }
 
-Q_DECLARE_METATYPE(KContacts::Impp)
-Q_DECLARE_TYPEINFO(KContacts::Impp, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(KContacts::Impp, Q_RELOCATABLE_TYPE);
+
 #endif // IMPP_H
