@@ -56,6 +56,9 @@ static const url_type_name url_type_names[] = {
     {"WORK", ResourceLocatorUrl::Work},
     {"OTHER", ResourceLocatorUrl::Other},
     {"PROFILE", ResourceLocatorUrl::Profile},
+    {"FTP", ResourceLocatorUrl::Ftp},
+    {"RESERVATION", ResourceLocatorUrl::Reservation},
+    {"APPINSTALLPAGE", ResourceLocatorUrl::AppInstallPage},
 };
 
 ResourceLocatorUrl::Type ResourceLocatorUrl::type() const
@@ -177,20 +180,6 @@ QString ResourceLocatorUrl::toString() const
     return str;
 }
 
-#if KCONTACTS_BUILD_DEPRECATED_SINCE(5, 88)
-void ResourceLocatorUrl::setParameters(const QMap<QString, QStringList> &params)
-{
-    d->mParamMap = ParameterMap::fromQMap(params);
-}
-#endif
-
-#if KCONTACTS_BUILD_DEPRECATED_SINCE(5, 88)
-QMap<QString, QStringList> ResourceLocatorUrl::parameters() const
-{
-    return d->mParamMap.toQMap();
-}
-#endif
-
 void ResourceLocatorUrl::setParams(const ParameterMap &params)
 {
     d->mParamMap = params;
